"""CRUD operations for the UAM relay database.

Provides typed async functions for each entity, accepting
``AsyncSession`` as the first parameter.  All read queries filter
``deleted_at IS NULL`` by default; ``_with_deleted()`` variants skip
that filter for admin inspection.

Modules::

    from uam.db.crud.agents import create_agent, get_agent_by_token, ...
    from uam.db.crud.messages import store_message, get_inbox, ...
    from uam.db.crud.handshakes import create_handshake, get_pending, ...
    from uam.db.crud.contacts import create_contact, get_contact, ...
    from uam.db.crud.reputation import init_reputation, get_reputation, ...
"""
